package com.tfis.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.tfis.common.annotation.Log;
import com.tfis.common.core.controller.BaseController;
import com.tfis.common.core.domain.AjaxResult;
import com.tfis.common.enums.BusinessType;
import com.tfis.system.domain.AircraftType;
import com.tfis.system.service.IAircraftTypeService;
import com.tfis.common.utils.poi.ExcelUtil;
import com.tfis.common.core.page.TableDataInfo;

/**
 * 机型信息管理Controller
 * 
 * @author allen
 * @date 2023-11-23
 */
@RestController
@RequestMapping("/system/type")
public class AircraftTypeController extends BaseController
{
    @Autowired
    private IAircraftTypeService aircraftTypeService;

    /**
     * 查询机型信息管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:type:list')")
    @GetMapping("/list")
    public TableDataInfo list(AircraftType aircraftType)
    {
        startPage();
        List<AircraftType> list = aircraftTypeService.selectAircraftTypeList(aircraftType);
        return getDataTable(list);
    }

    /**
     * 导出机型信息管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:type:export')")
    @Log(title = "机型信息管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AircraftType aircraftType)
    {
        List<AircraftType> list = aircraftTypeService.selectAircraftTypeList(aircraftType);
        ExcelUtil<AircraftType> util = new ExcelUtil<AircraftType>(AircraftType.class);
        util.exportExcel(response, list, "机型信息管理数据");
    }

    /**
     * 获取机型信息管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:type:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(aircraftTypeService.selectAircraftTypeById(id));
    }

    /**
     * 新增机型信息管理
     */
    @PreAuthorize("@ss.hasPermi('system:type:add')")
    @Log(title = "机型信息管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AircraftType aircraftType)
    {
        return toAjax(aircraftTypeService.insertAircraftType(aircraftType));
    }

    /**
     * 修改机型信息管理
     */
    @PreAuthorize("@ss.hasPermi('system:type:edit')")
    @Log(title = "机型信息管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AircraftType aircraftType)
    {
        return toAjax(aircraftTypeService.updateAircraftType(aircraftType));
    }

    /**
     * 删除机型信息管理
     */
    @PreAuthorize("@ss.hasPermi('system:type:remove')")
    @Log(title = "机型信息管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(aircraftTypeService.deleteAircraftTypeByIds(ids));
    }

    @GetMapping("/getOption")
    public AjaxResult getOption()
    {
        return success(aircraftTypeService.getOption());
    }
}
